@@ -49,11 +49,6 @@ class AdvNet:
             self.weights.append(newWeightsArr)
 
     def __str__(self):
-        # Parameter number calculation
-        weightSizes = [M.size for M in self.weights]
-        params = sum(weightSizes)
-
-        # String Forming and formating
         strlen = 56
         l1 = f"="
         l2 = f"Neural Net Characteristics:"
@@ -62,9 +57,8 @@ class AdvNet:
         for weights in self.weights:
             weightMedians.append(round(np.median(weights), 2))
         l4 = f"Weight Medians = {weightMedians}"
-        l6 = f"# of Parameters: {params}"
         l5 = f"="
-        return l1*strlen + '\n' + l2.center(strlen, ' ') + '\n' + l3.center(strlen, ' ') + '\n' + l4.center(strlen, ' ') + '\n' + l6.center(strlen, ' ') + '\n' + l5*strlen
+        return l1*strlen + '\n' + l2.center(strlen, ' ') + '\n' + l3.center(strlen, ' ') + '\n' + l4.center(strlen, ' ') + '\n' + l5*strlen
 
     def TweakWeights(self, Amplitude, Selection='default'):
         """
@@ -901,4 +895,4 @@ def CycleTrain(Net, inputData, validationData, startingTweakAmp=0.8,
         Forecast(Net, inputData, validationData, plotResults=plotResults)
 
     # Finish by giving back the improved net and its final mean error
-    return Net, bestError
\ No newline at end of file
+    return Net, bestError
